@@ -221,7 +221,7 @@ unif_test <- function(data, type = "all", p_value = "asymp",
                       K_CCF09 = 25, Poisson_rho = 0.5, Pycke_q = 0.5,
                       Rayleigh_m = 1, Riesz_s = 1, Rothman_t = 1 / 3,
                       Sobolev_vk2 = c(0, 0, 1), Softmax_kappa = 1,
-                      Stereo_a = 0, ...) {
+                      Stein_K = 10, Stein_cf = FALSE, Stereo_a = 0, ...) {
 
   # Read data's name
   data_name <- deparse(substitute(data))
@@ -386,7 +386,8 @@ unif_test <- function(data, type = "all", p_value = "asymp",
                     Poisson_rho = Poisson_rho, Pycke_q = Pycke_q,
                     Rayleigh_m = Rayleigh_m, Riesz_s = Riesz_s,
                     Rothman_t = Rothman_t, Sobolev_vk2 = Sobolev_vk2,
-                    Softmax_kappa = Softmax_kappa, Stereo_a = Stereo_a)
+                    Softmax_kappa = Softmax_kappa, Stein_K = Stein_K,
+                    Stein_cf = Stein_cf, Stereo_a = Stereo_a)
   stats_type_vec <- names(stat) # We can have Sobolev.1, Sobolev.2, etc.
 
   # Update the number of statistics (to count those Sobolev.1, Sobolev.2, etc.)
@@ -407,8 +408,9 @@ unif_test <- function(data, type = "all", p_value = "asymp",
                                K_CCF09 = K_CCF09, Poisson_rho = Poisson_rho,
                                Pycke_q = Pycke_q, Rayleigh_m = Rayleigh_m,
                                Riesz_s = Riesz_s, Rothman_t = Rothman_t,
-                               Sobolev_vk2 = Sobolev_vk2, Softmax_kappa =
-                                 Softmax_kappa, Stereo_a = Stereo_a,
+                               Sobolev_vk2 = Sobolev_vk2,
+                               Softmax_kappa = Softmax_kappa, Stein_K = Stein_K,
+                               Stein_cf = Stein_cf, Stereo_a = Stereo_a,
                                ...)$crit_val_MC
 
     } else {
@@ -449,8 +451,9 @@ unif_test <- function(data, type = "all", p_value = "asymp",
                                K_CCF09 = K_CCF09, Poisson_rho = Poisson_rho,
                                Pycke_q = Pycke_q, Rayleigh_m = Rayleigh_m,
                                Riesz_s = Riesz_s, Rothman_t = Rothman_t,
-                               Sobolev_vk2 = Sobolev_vk2, Softmax_kappa =
-                                 Softmax_kappa, Stereo_a = Stereo_a,
+                               Sobolev_vk2 = Sobolev_vk2,
+                               Softmax_kappa = Softmax_kappa, Stein_K = Stein_K,
+                               Stein_cf = Stein_cf, Stereo_a = Stereo_a,
                                ...)$stats_MC
 
     }
@@ -479,8 +482,10 @@ unif_test <- function(data, type = "all", p_value = "asymp",
                                  Cressie_t = Cressie_t, K_CCF09 = K_CCF09,
                                  Poisson_rho = Poisson_rho, Pycke_q = Pycke_q,
                                  Rayleigh_m = Rayleigh_m, Riesz_s = Riesz_s,
-                                 Rothman_t = Rothman_t, Sobolev_vk2 =
-                                   Sobolev_vk2, Softmax_kappa = Softmax_kappa,
+                                 Rothman_t = Rothman_t,
+                                 Sobolev_vk2 = Sobolev_vk2,
+                                 Softmax_kappa = Softmax_kappa,
+                                 Stein_K = Stein_K, Stein_cf = Stein_cf,
                                  Stereo_a = Stereo_a, ...)
 
     # Critical values
@@ -558,6 +563,7 @@ unif_test <- function(data, type = "all", p_value = "asymp",
          "Softmax" = c("Softmax_kappa" = ifelse(length(Softmax_kappa) == 1,
                                                 Softmax_kappa,
                                                 Softmax_kappa[par_i])),
+         "Stein" = c("Stein_K" = Stein_K, "Stein_cf" = Stein_cf),
          "Vacancy" = c("cov_a" = ifelse(length(cov_a) == 1, cov_a,
                                         cov_a[par_i])),
          "Watson" = NA,
@@ -610,8 +616,11 @@ unif_test <- function(data, type = "all", p_value = "asymp",
                            round(param, 3)),
          "Sobolev" = paste("Finite Sobolev test of circular uniformity with",
                            "vk2 =", capture.output(dput(unname(param)))),
-         "Softmax" = paste("Softmax test of circular uniformit with kappa =",
+         "Softmax" = paste("Softmax test of circular uniformity with kappa =",
                            round(param, 3)),
+         "Stein" = paste0("Stein test of circular uniformity (truncated to ",
+                          "K = ", param[1], " terms; ",
+                          ifelse(param[2], "cf", "mgf"), "-based)"),
          "Vacancy" = paste("Vacancy test of circular uniformity with a =",
                            round(param, 3)),
          "Watson" = "Watson test of circular uniformity",
@@ -654,6 +663,7 @@ unif_test <- function(data, type = "all", p_value = "asymp",
          "Sobolev" = paste("alternatives in the Fourier subspace",
                            "with vk2 \u2260 0"),
          "Softmax" = "any alternative to circular uniformity for kappa > 0",
+         "Stein" = "any alternative to circular uniformity",
          "Vacancy" = "any alternative to circular uniformity",
          "Watson" = "any alternative to circular uniformity",
          "Watson_1976" = "unclear consistency"
@@ -685,6 +695,7 @@ unif_test <- function(data, type = "all", p_value = "asymp",
          "Softmax" = c("Softmax_kappa" = ifelse(length(Softmax_kappa) == 1,
                                                 Softmax_kappa,
                                                 Softmax_kappa[par_i])),
+         "Stein" = c("Stein_K" = Stein_K, "Stein_cf" = Stein_cf),
          "Stereo" = c("Stereo_a" = ifelse(length(Stereo_a) == 1,
                                            Stereo_a, Stereo_a[par_i]))
       )
@@ -714,8 +725,11 @@ unif_test <- function(data, type = "all", p_value = "asymp",
                          "be used with s =", round(param, 3)),
          "Sobolev" = paste("Finite Sobolev test of spherical uniformity with",
                            "vk2 =", capture.output(dput(unname(param)))),
-         "Softmax" = paste("Softmax test of spherical uniformit with kappa =",
+         "Softmax" = paste("Softmax test of spherical uniformity with kappa =",
                            round(param, 3)),
+         "Stein" = paste0("Stein test of spherical uniformity (truncated to ",
+                          "K = ", param[1], " terms; ",
+                          ifelse(param[2], "cf", "mgf"), "-based)"),
          "Stereo" = paste("Stereographic projection test of spherical",
                            "uniformity with a =", round(param, 3))
       )
@@ -740,6 +754,7 @@ unif_test <- function(data, type = "all", p_value = "asymp",
          "Sobolev" = paste("alternatives in the spherical harmonics subspace",
                            "with vk2 \u2260 0"),
          "Softmax" = "any alternative to spherical uniformity for kappa > 0",
+         "Stein" = "any alternative to spherical uniformity",
          "Stereo" = "any alternative to spherical uniformity for |a| < 1"
       )
 
@@ -818,6 +833,7 @@ avail_cir_tests <- c("Ajne",
                      "Rothman",
                      "Sobolev",
                      "Softmax",
+                     "Stein",
                      "Vacancy",
                      "Watson",
                      "Watson_1976")
@@ -839,6 +855,7 @@ avail_sph_tests <- c("Ajne",
                      "Pycke",
                      "Sobolev",
                      "Softmax",
+                     "Stein",
                      "Stereo",
                      "Rayleigh",
                      "Rayleigh_HD",
